@@ -1,11 +1,11 @@
-# Copyrights 2006-2010 by Mark Overmeer.
+# Copyrights 2006-2011 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.00.
  
 package XML::Compile::Translate::Writer;
 use vars '$VERSION';
-$VERSION = '1.21';
+$VERSION = '1.22';
 
 use base 'XML::Compile::Translate';
 
@@ -13,7 +13,7 @@ use strict;
 use warnings;
 no warnings 'once';
 
-use Log::Report 'xml-compile', syntax => 'SHORT';
+use Log::Report   qw/xml-compile/;
 use List::Util    qw/first/;
 use Scalar::Util  qw/blessed/;
 use XML::Compile::Util qw/pack_type unpack_type type_of_node SCHEMA2001i
@@ -629,11 +629,15 @@ sub makeMixedElement
     }
 
     sub { my ($doc, $data) = @_;
+          defined $data or return;
+
           return $doc->importNode($data)
               if UNIVERSAL::isa($data, 'XML::LibXML::Element');
 
           my $copy = UNIVERSAL::isa($data, 'HASH') ? {%$data} : {_ => $data};
           my $content = delete $copy->{_};
+          defined $content or return;
+
           UNIVERSAL::isa($content, 'XML::LibXML::Node')
               or $content = $doc->createTextNode($content);
           my $node = $doc->importNode($content);
@@ -932,7 +936,6 @@ sub makeAnyElement
     my %no  = map { ($_ => 1) } @{$no  || []};
 
     $handler ||= 'SKIP_ALL';
-
     bless
     sub { my ($doc, $values) = @_;
           my @res;
